@@ -45,9 +45,9 @@ our @EXPORT = qw(
 	
 );
 
-our $VERSION = '1.031';
+our $VERSION = '1.032';
 
-sub dl_load_flags { 0x01 }
+sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
 require XSLoader;
 XSLoader::load('Gnome2::GConf', $VERSION);
